﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace LineChart
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
			// create line brushes
			firstBrush = new SolidBrush(Color.FromArgb(102, 154, 204));
			secondBrush = new SolidBrush(Color.FromArgb(0, 0, 99));
			thirdBrush = new SolidBrush(Color.FromArgb(206, 0, 0));
			
			lineChart.LegendRenderer.Background = new SolidBrush(Color.FromArgb(220, 220, 220));

			// create sample data series
			lineChart.Series.Add(
				new Series2D(
					new List<double> { 0,1,2,3,4,5,6,7,8,9,10,11 },
					new List<double> { 1,2,3,4,5,6,7,8,9,10,11,12 },
					labels
				)
				{ Title = "Series 1" });

			lineChart.Series.Add(
				new Series2D(
					new List<double> { 0,1,2,3,4,5,6,7,8,9,10,11 },
					new List<double> { 2,4,6,8,10,12,14,16,18,20,22,24 },
					labels
				)
				{ Title = "Series 2" });

			lineChart.Series.Add(
				new FunctionSeries("x*Sin(x)+x+5",12, 12)
				{ Title = "Series 3" });

			lineChart.XAxis.Interval = 1;

			// assign one brush per series
			lineChart.Plot.SeriesStyle = new MixedSeriesStyle()
			{
				CommonFills = new List<Brush>()
				{
					firstBrush, secondBrush, thirdBrush
				},
				CommonStrokes = new List<Brush>()
				{
					firstBrush, secondBrush, thirdBrush
				},
				UniformStrokeThickness = 5
			};

			lineChart.ShowXRangeSelector = true;
			lineChart.XScrollRangeMin = -50;
			lineChart.XScrollRangeMax = 50;

			lineChart.ShowYRangeSelector = true;
			lineChart.YScrollRangeMin = -50;
			lineChart.YScrollRangeMax = 50;

			// set up grid type combo box
			cbxGridType.Items.Add(GridType.Crossed);
			cbxGridType.Items.Add(GridType.Horizontal);
			cbxGridType.Items.Add(GridType.None);
			cbxGridType.Items.Add(GridType.Vertical);
			cbxGridType.SelectedIndex = 0;
			lineChart.GridType = GridType.Crossed;

			// set up line type combo box
			cbxLineType.Items.Add(LineType.Polyline);
			cbxLineType.Items.Add(LineType.Step);
			cbxLineType.Items.Add(LineType.Curve);
			cbxLineType.SelectedIndex = 0;
			lineChart.LineType = LineType.Polyline;
		}

		void chbShowXTicks_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowXTicks = !lineChart.ShowXTicks;
			lineChart.Invalidate();
		}

		void chbShowYTicks_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowYTicks = !lineChart.ShowYTicks;
			lineChart.Invalidate();
		}

		void chbShowXCoords_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowXCoordinates = !lineChart.ShowXCoordinates;
			lineChart.Invalidate();
		}

		void chbShowYCoords_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowYCoordinates = !lineChart.ShowYCoordinates;
			lineChart.Invalidate();
		}

		void chbShowLegend_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowLegend = !lineChart.ShowLegend;
			lineChart.Invalidate();
		}

		void chbShowDataLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (chbShowDataLabels.Checked)
				lineChart.ShowDataLabels = LabelKinds.All;
			else
				lineChart.ShowDataLabels = LabelKinds.None;
			lineChart.Invalidate();
		}

		void tbXAxisMax_Scroll(object sender, EventArgs e)
		{
			lineChart.XAxis.MaxValue = tbXAxisMax.Value;
			lineChart.Invalidate();
		}

		void tbYAxisMax_Scroll(object sender, EventArgs e)
		{
			lineChart.YAxis.MaxValue = tbYAxisMax.Value;
			lineChart.Invalidate();
		}

		void cbxGridType_SelectedValueChanged(object sender, EventArgs e)
		{
			lineChart.GridType = (GridType)cbxGridType.SelectedItem;
			lineChart.Invalidate();
		}

		void tbXAxisMin_Scroll(object sender, EventArgs e)
		{
			lineChart.XAxis.MinValue = tbXAxisMin.Value;
			lineChart.Invalidate();
		}

		void tbYAxisMin_Scroll(object sender, EventArgs e)
		{
			lineChart.YAxis.MinValue = tbYAxisMin.Value;
			lineChart.Invalidate();
		}

		void chbScrollGrid_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.PinGrid = !lineChart.PinGrid;
		}

		void cbxLineType_SelectedValueChanged(object sender, EventArgs e)
		{
			lineChart.LineType = (LineType)cbxLineType.SelectedItem;
			lineChart.Invalidate();
		}

		private void tbXRangeMin_Scroll(object sender, EventArgs e)
		{
			lineChart.XScrollRangeMin = tbXRangeMin.Value;
			lineChart.Invalidate();
		}

		private void tbXRangeMax_Scroll(object sender, EventArgs e)
		{
			lineChart.XScrollRangeMax = tbXRangeMax.Value;
			lineChart.Invalidate();
		}

		private void tbYRangeMax_Scroll(object sender, EventArgs e)
		{
			lineChart.YScrollRangeMax= tbYRangeMax.Value;
			lineChart.Invalidate();
		}

		private void chbShowXRange_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowXRangeSelector = chbShowXRange.Checked;
			lineChart.XScrollRangeMin = tbXRangeMin.Value = -50;
			lineChart.XScrollRangeMax = tbXRangeMax.Value = 50;
		}

		private void chbShowYRange_CheckedChanged(object sender, EventArgs e)
		{
			lineChart.ShowYRangeSelector = chbShowYRange.Checked;
			lineChart.YScrollRangeMin = tbYRangeMin.Value = -50;
			lineChart.YScrollRangeMax = tbYRangeMax.Value = 50;
		}

		private void tbYRangeMin_Scroll(object sender, EventArgs e)
		{
			lineChart.YScrollRangeMin = tbYRangeMin.Value;
			lineChart.Invalidate();
		}

		List<string> labels = new List<string>()
		{
			"one", "two", "three", "four", "five", "six",
			"seven", "eight", "nine", "ten", "eleven", "twelve"
		};

		SolidBrush firstBrush;
		SolidBrush secondBrush;
		SolidBrush thirdBrush;

		private void label5_Click(object sender, EventArgs e)
		{

		}

		private void label8_Click(object sender, EventArgs e)
		{

		}

		private void label9_Click(object sender, EventArgs e)
		{

		}

		private void label10_Click(object sender, EventArgs e)
		{

		}

	}
}